@@ -24,40 +24,15 @@
 
 /// @cond PRIVATE
 
-
-namespace Qgs3DSymbolImpl
+void QgsFeature3DHandler::updateZRangeFromPositions( const QVector<QVector3D> &positions )
 {
-
-  Qt3DCore::QEntity *entityFromHandler( QgsFeature3DHandler *handler, const Qgs3DMapSettings &map, QgsVectorLayer *layer )
+  for ( const QVector3D &pos : positions )
   {
-    Qgs3DRenderContext context( map );
-
-    QgsExpressionContext exprContext( Qgs3DUtils::globalProjectLayerExpressionContext( layer ) );
-    exprContext.setFields( layer->fields() );
-    context.setExpressionContext( exprContext );
-
-    QSet<QString> attributeNames;
-    if ( !handler->prepare( context, attributeNames ) )
-      return nullptr;
-
-    // build the feature request
-    QgsFeatureRequest req;
-    req.setDestinationCrs( map.crs(), map.transformContext() );
-    req.setSubsetOfAttributes( attributeNames, layer->fields() );
-
-    QgsFeature f;
-    QgsFeatureIterator fi = layer->getFeatures( req );
-    while ( fi.nextFeature( f ) )
-    {
-      context.expressionContext().setFeature( f );
-      handler->processFeature( f, context );
-    }
-
-    Qt3DCore::QEntity *entity = new Qt3DCore::QEntity;
-    handler->finalize( entity, context );
-    return entity;
+    if ( pos.y() < mZMin )
+      mZMin = pos.y();
+    if ( pos.y() > mZMax )
+      mZMax = pos.y();
   }
-
 }
 
 /// @endcond
