@@ -41,56 +41,21 @@ class QgsPathResolver;
  * \class QgsSimpleMarkerSymbolLayerBase
  * \brief Abstract base class for simple marker symbol layers. Handles creation of the symbol shapes but
  * leaves the actual drawing of the symbols to subclasses.
- * \since QGIS 2.16
  */
 class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
 {
 
   public:
 
-    //! Marker symbol shapes
-    enum Shape
-    {
-      Square, //!< Square
-      Diamond, //!< Diamond
-      Pentagon, //!< Pentagon
-      Hexagon, //!< Hexagon
-      Triangle, //!< Triangle
-      EquilateralTriangle, //!< Equilateral triangle
-      Star, //!< Star
-      Arrow, //!< Arrow
-      Circle, //!< Circle
-      Cross, //!< Cross (lines only)
-      CrossFill, //!< Solid filled cross
-      Cross2, //!< Rotated cross (lines only), "x" shape
-      Line, //!< Vertical line
-      ArrowHead, //!< Right facing arrow head (unfilled, lines only)
-      ArrowHeadFilled, //!< Right facing filled arrow head
-      SemiCircle, //!< Semi circle (top half)
-      ThirdCircle, //!< One third circle (top left third)
-      QuarterCircle, //!< Quarter circle (top left quarter)
-      QuarterSquare, //!< Quarter square (top left quarter)
-      HalfSquare, //!< Half square (left half)
-      DiagonalHalfSquare, //!< Diagonal half square (bottom left half)
-      RightHalfTriangle, //!< Right half of triangle
-      LeftHalfTriangle, //!< Left half of triangle
-      Octagon, //!< Octagon (since QGIS 3.18)
-      SquareWithCorners, //!< A square with diagonal corners (since QGIS 3.18)
-      AsteriskFill, //!< A filled asterisk shape (since QGIS 3.18)
-      HalfArc, //!< A line-only half arc (since QGIS 3.20)
-      ThirdArc, //!< A line-only one third arc (since QGIS 3.20)
-      QuarterArc, //!< A line-only one quarter arc (since QGIS 3.20)
-    };
-
     //! Returns a list of all available shape types.
-    static QList< QgsSimpleMarkerSymbolLayerBase::Shape > availableShapes();
+    static QList< Qgis::MarkerShape > availableShapes();
 
     /**
      * Returns TRUE if a symbol shape has a fill.
      * \param shape shape to test
      * \returns TRUE if shape uses a fill, or FALSE if shape uses lines only
      */
-    static bool shapeIsFilled( QgsSimpleMarkerSymbolLayerBase::Shape shape );
+    static bool shapeIsFilled( Qgis::MarkerShape shape );
 
     /**
      * Constructor for QgsSimpleMarkerSymbolLayerBase.
@@ -99,7 +64,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
     * \param angle symbol rotation angle
     * \param scaleMethod scaling method for data defined scaling
     */
-    QgsSimpleMarkerSymbolLayerBase( QgsSimpleMarkerSymbolLayerBase::Shape shape = Circle,
+    QgsSimpleMarkerSymbolLayerBase( Qgis::MarkerShape shape = Qgis::MarkerShape::Circle,
                                     double size = DEFAULT_SIMPLEMARKER_SIZE,
                                     double angle = DEFAULT_SIMPLEMARKER_ANGLE,
                                     Qgis::ScaleMethod scaleMethod = DEFAULT_SCALE_METHOD );
@@ -110,14 +75,14 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
      * Returns the shape for the rendered marker symbol.
      * \see setShape()
      */
-    QgsSimpleMarkerSymbolLayerBase::Shape shape() const { return mShape; }
+    Qgis::MarkerShape shape() const { return mShape; }
 
     /**
      * Sets the rendered marker shape.
      * \param shape new marker shape
      * \see shape()
      */
-    void setShape( QgsSimpleMarkerSymbolLayerBase::Shape shape ) { mShape = shape; }
+    void setShape( Qgis::MarkerShape shape ) { mShape = shape; }
 
     /**
      * Attempts to decode a string representation of a shape name to the corresponding
@@ -127,7 +92,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
      * \returns decoded name
      * \see encodeShape()
      */
-    static QgsSimpleMarkerSymbolLayerBase::Shape decodeShape( const QString &name, bool *ok = nullptr );
+    static Qgis::MarkerShape decodeShape( const QString &name, bool *ok = nullptr );
 
     /**
      * Encodes a shape to its string representation.
@@ -135,7 +100,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
      * \returns encoded string
      * \see decodeShape()
      */
-    static QString encodeShape( QgsSimpleMarkerSymbolLayerBase::Shape shape );
+    static QString encodeShape( Qgis::MarkerShape shape );
 
     void startRender( QgsSymbolRenderContext &context ) override;
     void stopRender( QgsSymbolRenderContext &context ) override;
@@ -147,12 +112,12 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
     /**
      * Prepares the layer for drawing the specified shape (QPolygonF version)
      */
-    bool prepareMarkerShape( Shape shape );
+    bool prepareMarkerShape( Qgis::MarkerShape shape );
 
     /**
      * Prepares the layer for drawing the specified shape (QPainterPath version)
      */
-    bool prepareMarkerPath( Shape symbol );
+    bool prepareMarkerPath( Qgis::MarkerShape symbol );
 
     /**
      * Creates a polygon representing the specified shape.
@@ -160,7 +125,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
      * \param polygon destination polygon for shape
      * \returns TRUE if shape was successfully stored in polygon
      */
-    bool shapeToPolygon( Shape shape, QPolygonF &polygon ) const;
+    bool shapeToPolygon( Qgis::MarkerShape shape, QPolygonF &polygon ) const;
 
     /**
      * Calculates the desired size of the marker, considering data defined size overrides.
@@ -187,7 +152,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
     QPainterPath mPath;
 
     //! Symbol shape
-    Shape mShape;
+    Qgis::MarkerShape mShape;
 
   private:
 
@@ -199,7 +164,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayerBase : public QgsMarkerSymbolLayer
      * in the path argument.
      * \param path transformed painter path representing shape to draw
      */
-    virtual void draw( QgsSymbolRenderContext &context, QgsSimpleMarkerSymbolLayerBase::Shape shape, const QPolygonF &polygon, const QPainterPath &path ) = 0 SIP_FORCE;
+    virtual void draw( QgsSymbolRenderContext &context, Qgis::MarkerShape shape, const QPolygonF &polygon, const QPainterPath &path ) = 0 SIP_FORCE;
 };
 
 /**
@@ -221,7 +186,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
     * \param strokeColor stroke color for symbol
     * \param penJoinStyle join style for stroke pen
     */
-    QgsSimpleMarkerSymbolLayer( QgsSimpleMarkerSymbolLayerBase::Shape shape = Circle,
+    QgsSimpleMarkerSymbolLayer( Qgis::MarkerShape shape = Qgis::MarkerShape::Circle,
                                 double size = DEFAULT_SIMPLEMARKER_SIZE,
                                 double angle = DEFAULT_SIMPLEMARKER_ANGLE,
                                 Qgis::ScaleMethod scaleMethod = DEFAULT_SCALE_METHOD,
@@ -250,6 +215,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
     // reimplemented from base classes
 
     QString layerType() const override;
+    Qgis::SymbolLayerFlags flags() const override;
     void startRender( QgsSymbolRenderContext &context ) override;
     void renderPoint( QPointF point, QgsSymbolRenderContext &context ) override;
     QVariantMap properties() const override;
@@ -257,8 +223,8 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
     void writeSldMarker( QDomDocument &doc, QDomElement &element, const QVariantMap &props ) const override;
     QString ogrFeatureStyle( double mmScaleFactor, double mapUnitScaleFactor ) const override;
     bool writeDxf( QgsDxfExport &e, double mmMapUnitScaleFactor, const QString &layerName, QgsSymbolRenderContext &context, QPointF shift = QPointF( 0.0, 0.0 ) ) const override;
-    void setOutputUnit( QgsUnitTypes::RenderUnit unit ) override;
-    QgsUnitTypes::RenderUnit outputUnit() const override;
+    void setOutputUnit( Qgis::RenderUnit unit ) override;
+    Qgis::RenderUnit outputUnit() const override;
     void setMapUnitScale( const QgsMapUnitScale &scale ) override;
     QgsMapUnitScale mapUnitScale() const override;
     bool usesMapUnits() const override;
@@ -292,7 +258,6 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
      * \see setStrokeStyle()
      * \see strokeColor()
      * \see penJoinStyle()
-     * \since QGIS 2.4
     */
     Qt::PenStyle strokeStyle() const { return mStrokeStyle; }
 
@@ -302,7 +267,6 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
      * \see strokeStyle()
      * \see setStrokeColor()
      * \see setPenJoinStyle()
-     * \since QGIS 2.4
     */
     void setStrokeStyle( Qt::PenStyle strokeStyle ) { mStrokeStyle = strokeStyle; }
 
@@ -312,7 +276,6 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
      * \see penCapStyle()
      * \see strokeColor()
      * \see strokeStyle()
-     * \since QGIS 2.16
     */
     Qt::PenJoinStyle penJoinStyle() const { return mPenJoinStyle; }
 
@@ -323,7 +286,6 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
      * \see setPenCapStyle()
      * \see setStrokeColor()
      * \see setStrokeStyle()
-     * \since QGIS 2.16
     */
     void setPenJoinStyle( Qt::PenJoinStyle style ) { mPenJoinStyle = style; }
 
@@ -371,7 +333,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
      * \see setStrokeWidth()
      * \see setStrokeWidthMapUnitScale()
      */
-    void setStrokeWidthUnit( QgsUnitTypes::RenderUnit u ) { mStrokeWidthUnit = u; }
+    void setStrokeWidthUnit( Qgis::RenderUnit u ) { mStrokeWidthUnit = u; }
 
     /**
      * Returns the unit for the width of the marker's stroke.
@@ -379,7 +341,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
      * \see strokeWidth()
      * \see strokeWidthMapUnitScale()
      */
-    QgsUnitTypes::RenderUnit strokeWidthUnit() const { return mStrokeWidthUnit; }
+    Qgis::RenderUnit strokeWidthUnit() const { return mStrokeWidthUnit; }
 
     /**
      * Sets the map scale for the width of the marker's stroke.
@@ -421,7 +383,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
     //! Stroke width
     double mStrokeWidth = 0;
     //! Stroke width units
-    QgsUnitTypes::RenderUnit mStrokeWidthUnit = QgsUnitTypes::RenderMillimeters;
+    Qgis::RenderUnit mStrokeWidthUnit = Qgis::RenderUnit::Millimeters;
     //! Stroke width map unit scale
     QgsMapUnitScale mStrokeWidthMapUnitScale;
     //! Stroke pen join style
@@ -453,7 +415,7 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
 
   private:
     // cppcheck-suppress unusedPrivateFunction
-    void draw( QgsSymbolRenderContext &context, QgsSimpleMarkerSymbolLayerBase::Shape shape, const QPolygonF &polygon, const QPainterPath &path ) override SIP_FORCE;
+    void draw( QgsSymbolRenderContext &context, Qgis::MarkerShape shape, const QPolygonF &polygon, const QPainterPath &path ) override SIP_FORCE;
 
     double mCachedOpacity = 1.0;
 
@@ -464,7 +426,6 @@ class CORE_EXPORT QgsSimpleMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
  * \class QgsFilledMarkerSymbolLayer
  * \brief Filled marker symbol layer, consisting of a shape which is rendered using a QgsFillSymbol. This allows
  * the symbol to support advanced styling of the interior and stroke of the shape.
- * \since QGIS 2.16
  */
 class CORE_EXPORT QgsFilledMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayerBase
 {
@@ -477,7 +438,7 @@ class CORE_EXPORT QgsFilledMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
     * \param angle symbol rotation angle
     * \param scaleMethod size scaling method
     */
-    QgsFilledMarkerSymbolLayer( QgsSimpleMarkerSymbolLayerBase::Shape shape = Circle,
+    QgsFilledMarkerSymbolLayer( Qgis::MarkerShape shape = Qgis::MarkerShape::Circle,
                                 double size = DEFAULT_SIMPLEMARKER_SIZE,
                                 double angle = DEFAULT_SIMPLEMARKER_ANGLE,
                                 Qgis::ScaleMethod scaleMethod = DEFAULT_SCALE_METHOD );
@@ -494,6 +455,8 @@ class CORE_EXPORT QgsFilledMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
     QString layerType() const override;
     void startRender( QgsSymbolRenderContext &context ) override;
     void stopRender( QgsSymbolRenderContext &context ) override;
+    void startFeatureRender( const QgsFeature &feature, QgsRenderContext &context ) override;
+    void stopFeatureRender( const QgsFeature &feature, QgsRenderContext &context ) override;
     QVariantMap properties() const override;
     QgsFilledMarkerSymbolLayer *clone() const override SIP_FACTORY;
     QgsSymbol *subSymbol() override;
@@ -504,6 +467,7 @@ class CORE_EXPORT QgsFilledMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
     void setColor( const QColor &c ) override;
     QColor color() const override;
     bool usesMapUnits() const override;
+    void setOutputUnit( Qgis::RenderUnit unit ) override;
 
   private:
 #ifdef SIP_RUN
@@ -511,7 +475,7 @@ class CORE_EXPORT QgsFilledMarkerSymbolLayer : public QgsSimpleMarkerSymbolLayer
 #endif
 
     // cppcheck-suppress unusedPrivateFunction
-    void draw( QgsSymbolRenderContext &context, QgsSimpleMarkerSymbolLayerBase::Shape shape, const QPolygonF &polygon, const QPainterPath &path ) override SIP_FORCE;
+    void draw( QgsSymbolRenderContext &context, Qgis::MarkerShape shape, const QPolygonF &polygon, const QPainterPath &path ) override SIP_FORCE;
 
     //! Fill subsymbol
     std::unique_ptr< QgsFillSymbol > mFill;
@@ -546,25 +510,19 @@ class CORE_EXPORT QgsSvgMarkerSymbolLayer : public QgsMarkerSymbolLayer
     /**
      * Turns relative paths in properties map to absolute when reading and vice versa when writing.
      * Used internally when reading/writing symbols.
-     * \since QGIS 3.0
      */
     static void resolvePaths( QVariantMap &properties, const QgsPathResolver &pathResolver, bool saving );
 
     // implemented from base classes
 
     QString layerType() const override;
-
+    Qgis::SymbolLayerFlags flags() const override;
     void startRender( QgsSymbolRenderContext &context ) override;
-
     void stopRender( QgsSymbolRenderContext &context ) override;
-
     void renderPoint( QPointF point, QgsSymbolRenderContext &context ) override;
-
     QVariantMap properties() const override;
     bool usesMapUnits() const override;
-
     QgsSvgMarkerSymbolLayer *clone() const override SIP_FACTORY;
-
     void writeSldMarker( QDomDocument &doc, QDomElement &element, const QVariantMap &props ) const override;
 
     /**
@@ -610,7 +568,8 @@ class CORE_EXPORT QgsSvgMarkerSymbolLayer : public QgsMarkerSymbolLayer
     /**
      * Returns the marker aspect ratio between width and height to be used in rendering,
      * if the value set is lower or equal to 0 the aspect ratio will be preserved in rendering
-     * \see setFixedAspectRatio() QgsSvgCache
+     * \see setFixedAspectRatio()
+     * \see QgsSvgCache
      */
     double fixedAspectRatio() const { return mFixedAspectRatio; }
 
@@ -618,7 +577,8 @@ class CORE_EXPORT QgsSvgMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * Set the marker aspect ratio between width and height to be used in rendering,
      * if the value set is lower or equal to 0 the aspect ratio will be preserved in rendering
      * \param ratio Fixed Aspect Ratio
-     * \see fixedAspectRatio() QgsSvgCache
+     * \see fixedAspectRatio()
+     * \see QgsSvgCache
      */
     void setFixedAspectRatio( double ratio ) { mFixedAspectRatio = ratio; }
 
@@ -648,19 +608,19 @@ class CORE_EXPORT QgsSvgMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * \param unit width units
      * \see strokeWidthUnit()
     */
-    void setStrokeWidthUnit( QgsUnitTypes::RenderUnit unit ) { mStrokeWidthUnit = unit; }
+    void setStrokeWidthUnit( Qgis::RenderUnit unit ) { mStrokeWidthUnit = unit; }
 
     /**
      * Returns the units for the stroke width.
      * \see strokeWidthUnit()
     */
-    QgsUnitTypes::RenderUnit strokeWidthUnit() const { return mStrokeWidthUnit; }
+    Qgis::RenderUnit strokeWidthUnit() const { return mStrokeWidthUnit; }
 
     void setStrokeWidthMapUnitScale( const QgsMapUnitScale &scale ) { mStrokeWidthMapUnitScale = scale; }
     const QgsMapUnitScale &strokeWidthMapUnitScale() const { return mStrokeWidthMapUnitScale; }
 
-    void setOutputUnit( QgsUnitTypes::RenderUnit unit ) override;
-    QgsUnitTypes::RenderUnit outputUnit() const override;
+    void setOutputUnit( Qgis::RenderUnit unit ) override;
+    Qgis::RenderUnit outputUnit() const override;
 
     void setMapUnitScale( const QgsMapUnitScale &scale ) override;
     QgsMapUnitScale mapUnitScale() const override;
@@ -696,7 +656,7 @@ class CORE_EXPORT QgsSvgMarkerSymbolLayer : public QgsMarkerSymbolLayer
     double mStrokeWidth;
     QMap<QString, QgsProperty> mParameters;
 
-    QgsUnitTypes::RenderUnit mStrokeWidthUnit;
+    Qgis::RenderUnit mStrokeWidthUnit;
     QgsMapUnitScale mStrokeWidthMapUnitScale;
 
   private:
@@ -739,20 +699,18 @@ class CORE_EXPORT QgsRasterMarkerSymbolLayer : public QgsMarkerSymbolLayer
     /**
      * Turns relative paths in properties map to absolute when reading and vice versa when writing.
      * Used internally when reading/writing symbols.
-     * \since QGIS 3.0
      */
     static void resolvePaths( QVariantMap &properties, const QgsPathResolver &pathResolver, bool saving );
 
     // implemented from base classes
 
     QString layerType() const override;
-
+    Qgis::SymbolLayerFlags flags() const override;
     void renderPoint( QPointF point, QgsSymbolRenderContext &context ) override;
-
     QVariantMap properties() const override;
-
     QgsRasterMarkerSymbolLayer *clone() const override SIP_FACTORY;
     bool usesMapUnits() const override;
+    QColor color() const override;
 
     /**
      * Calculates the marker aspect ratio between width and height.
@@ -819,7 +777,8 @@ class CORE_EXPORT QgsRasterMarkerSymbolLayer : public QgsMarkerSymbolLayer
     /**
      * Returns the marker aspect ratio between width and height to be used in rendering,
      * if the value set is lower or equal to 0 the aspect ratio will be preserved in rendering
-     * \see setFixedAspectRatio() QgsSvgCache
+     * \see setFixedAspectRatio()
+     * \see QgsSvgCache
      */
     double fixedAspectRatio() const { return mFixedAspectRatio; }
 
@@ -827,7 +786,8 @@ class CORE_EXPORT QgsRasterMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * Set the marker aspect ratio between width and height to be used in rendering,
      * if the value set is lower or equal to 0 the aspect ratio will be preserved in rendering
      * \param ratio Fixed Aspect Ratio
-     * \see fixedAspectRatio() QgsSvgCache
+     * \see fixedAspectRatio()
+     * \see QgsSvgCache
      */
     void setFixedAspectRatio( double ratio ) { mFixedAspectRatio = ratio; }
 
@@ -838,6 +798,27 @@ class CORE_EXPORT QgsRasterMarkerSymbolLayer : public QgsMarkerSymbolLayer
 
   protected:
 
+    /**
+     * Sets common class properties from a \a properties map.
+     *
+     * \since QGIS 3.26
+     */
+    void setCommonProperties( const QVariantMap &properties );
+
+    /**
+     * Copies common properties to another layer.
+     *
+     * \since QGIS 3.26
+     */
+    void copyCommonProperties( QgsRasterMarkerSymbolLayer *other ) const;
+
+    /**
+     * Fetches the image to render.
+     *
+     * \note Not available in Python bindings
+     */
+    virtual QImage fetchImage( QgsRenderContext &context, const QString &path, QSize size, bool preserveAspectRatio, double opacity ) const SIP_SKIP;
+
     QString mPath;
     //! The marker default opacity
     double mOpacity = 1.0;
@@ -906,6 +887,7 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
     // implemented from base classes
 
     QString layerType() const override;
+    Qgis::SymbolLayerFlags flags() const override;
 
     void startRender( QgsSymbolRenderContext &context ) override;
 
@@ -919,6 +901,7 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
 
     void writeSldMarker( QDomDocument &doc, QDomElement &element, const QVariantMap &props ) const override;
     bool usesMapUnits() const override;
+    void setOutputUnit( Qgis::RenderUnit unit ) override;
 
     // new methods
 
@@ -976,7 +959,6 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * \see strokeWidthUnit()
      * \see strokeWidthMapUnitScale()
      *
-     * \since QGIS 2.16
     */
     double strokeWidth() const { return mStrokeWidth; }
 
@@ -987,7 +969,6 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * \see setStrokeWidthUnit()
      * \see setStrokeWidthMapUnitScale()
      *
-     * \since QGIS 2.16
     */
     void setStrokeWidth( double width ) { mStrokeWidth = width; }
 
@@ -998,9 +979,8 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * \see strokeWidth()
      * \see strokeWidthMapUnitScale()
      *
-     * \since QGIS 2.16
     */
-    QgsUnitTypes::RenderUnit strokeWidthUnit() const { return mStrokeWidthUnit; }
+    Qgis::RenderUnit strokeWidthUnit() const { return mStrokeWidthUnit; }
 
     /**
      * Sets the stroke width \a unit.
@@ -1008,9 +988,8 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * \see strokeWidthUnit()
      * \see setStrokeWidth()
      * \see setStrokeWidthMapUnitScale()
-     * \since QGIS 2.16
     */
-    void setStrokeWidthUnit( QgsUnitTypes::RenderUnit unit ) { mStrokeWidthUnit = unit; }
+    void setStrokeWidthUnit( Qgis::RenderUnit unit ) { mStrokeWidthUnit = unit; }
 
     /**
      * Returns the stroke width map unit scale.
@@ -1019,7 +998,6 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * \see strokeWidth()
      * \see strokeWidthUnit()
      *
-     * \since QGIS 2.16
     */
     const QgsMapUnitScale &strokeWidthMapUnitScale() const { return mStrokeWidthMapUnitScale; }
 
@@ -1030,7 +1008,6 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      * \see setStrokeWidth()
      * \see setStrokeWidthUnit()
      *
-     * \since QGIS 2.16
      */
     void setStrokeWidthMapUnitScale( const QgsMapUnitScale &scale ) { mStrokeWidthMapUnitScale = scale; }
 
@@ -1039,7 +1016,6 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      *
      * \see setPenJoinStyle()
      *
-     * \since QGIS 2.16
     */
     Qt::PenJoinStyle penJoinStyle() const { return mPenJoinStyle; }
 
@@ -1048,7 +1024,6 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
      *
      * \see penJoinStyle()
      *
-     * \since QGIS 2.16
     */
     void setPenJoinStyle( Qt::PenJoinStyle style ) { mPenJoinStyle = style; }
 
@@ -1071,7 +1046,7 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
 
     QColor mStrokeColor;
     double mStrokeWidth;
-    QgsUnitTypes::RenderUnit mStrokeWidthUnit;
+    Qgis::RenderUnit mStrokeWidthUnit;
     QgsMapUnitScale mStrokeWidthMapUnitScale;
     Qt::PenJoinStyle mPenJoinStyle;
 
@@ -1089,6 +1064,69 @@ class CORE_EXPORT QgsFontMarkerSymbolLayer : public QgsMarkerSymbolLayer
     double calculateSize( QgsSymbolRenderContext &context );
 };
 
+
+/**
+ * \ingroup core
+ * \class QgsAnimatedMarkerSymbolLayer
+ * \brief Animated marker symbol layer class.
+ *
+ * The QgsAnimatedMarkerSymbolLayer class renders frames from an animated raster image source (e.g.
+ * an animated GIF) during temporal animations or map exports.
+ *
+ * \since QGIS 3.26
+ */
+class CORE_EXPORT QgsAnimatedMarkerSymbolLayer : public QgsRasterMarkerSymbolLayer
+{
+  public:
+
+    /**
+     * Constructor for animated marker symbol layer using the specified source image \a path.
+     */
+    QgsAnimatedMarkerSymbolLayer( const QString &path = QString(),
+                                  double size = DEFAULT_RASTERMARKER_SIZE,
+                                  double angle = DEFAULT_RASTERMARKER_ANGLE );
+
+    ~QgsAnimatedMarkerSymbolLayer() override;
+
+    // static stuff
+
+    /**
+     * Creates an animated marker symbol layer from a string map of \a properties.
+     */
+    static QgsSymbolLayer *create( const QVariantMap &properties = QVariantMap() ) SIP_FACTORY; // cppcheck-suppress duplInheritedMember
+
+    // implemented from base classes
+
+    QString layerType() const override;
+    QVariantMap properties() const override;
+    QgsAnimatedMarkerSymbolLayer *clone() const override SIP_FACTORY;
+
+    /**
+     * Sets the marker frame \a rate in frame per second.
+     *
+     * \see frameRate()
+     */
+    void setFrameRate( double rate ) { mFrameRateFps = rate; }
+
+    /**
+     * Returns the marker frame rate in frame per second.
+     *
+     * \see setFrameRate()
+     */
+    double frameRate() const { return mFrameRateFps; }
+
+    void startRender( QgsSymbolRenderContext &context ) override;
+
+  protected:
+    QImage fetchImage( QgsRenderContext &context, const QString &path, QSize size, bool preserveAspectRatio, double opacity ) const override SIP_SKIP;
+
+  private:
+    double mFrameRateFps = 10;
+    bool mStaticPath = false;
+    mutable QSet< QString > mPreparedPaths;
+
+};
+
 // clazy:excludeall=qstring-allocations
 
 #endif
